@@ -2,6 +2,5 @@ class Controller:
     def start(self, deployment):
         raise NotImplemented
 
-    def stop(self, deployment):
+    def stop(self, deployment_id):
         raise NotImplemented
-
