@@ -1,3 +1,3 @@
 """ Message Queue clients"""
-from .kafka_client import KafkaClient
+# from .kafka_client import KafkaClient
 from .zmq_client import ZMQClient
